*********
Changelog
*********
v2.0.4
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.5
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.6b
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.7
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.8b
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.9
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.10
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.12
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.15
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.0.18
=======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.1.2
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.1.5
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md
* Updated README
* Added README.md

v2.1.7
======
:Date: June 07, 2023

* Update README.md
* Update README.md
* Update .gitignore
* moving docker folder to R-release & Python-release branches so can be triggered with actions
* updates to make rmkl work with r-base 4.0.5 in conda
* adding cairo, hdf5r dependencies
* changing how R is installed so we get R > 4 and rmkl from conda
* setting source repo mirror
* docker debug
* docker for actionet essentials
* remove docker from master
* cleanup
* specified branches
* any branch
* testing
* on release build
* blah
* a
* updating branch names
* blah
* trigger
* any release branch
* branch hooks
* master trigger
* single quote
* branch names
* python build
* fixed branch names
* renamed workflow
* cleanup
* adding github workflows for R & python branches
* fixed python-devel link in readme
* Update README.md
* Update README.md
* Update README.md
* Update README.md

